@@ -27,20 +27,20 @@ enum Commands {
 }
 
 impl Commands {
-    pub fn run(self) -> Result<()> {
+    pub async fn run(self) -> Result<()> {
         match self {
             Self::Generate(cmd) => cmd.run(),
             Self::Get(cmd) => cmd.run(),
-            Self::Ls(cmd) => cmd.run(),
+            Self::Ls(cmd) => cmd.run().await,
             Self::Set(cmd) => cmd.run(),
         }
     }
 }
 
 impl Config {
-    pub fn run(self) -> Result<()> {
+    pub async fn run(self) -> Result<()> {
         let cmd = self.command.unwrap_or(Commands::Ls(self.ls));
 
-        cmd.run()
+        cmd.run().await
     }
 }
