@@ -75,6 +75,8 @@ pub static XDG_STATE_HOME: Lazy<PathBuf> =
 
 /// always display "friendly" errors even in debug mode
 pub static MISE_FRIENDLY_ERROR: Lazy<bool> = Lazy::new(|| var_is_true("MISE_FRIENDLY_ERROR"));
+pub static MISE_TOOL_STUB: Lazy<bool> =
+    Lazy::new(|| ARGS.read().unwrap().get(1).map(|s| s.as_str()) == Some("tool-stub"));
 pub static MISE_NO_CONFIG: Lazy<bool> = Lazy::new(|| var_is_true("MISE_NO_CONFIG"));
 /// true if RUST_BACKTRACE is set (enables detailed error tracebacks)
 pub static RUST_BACKTRACE: Lazy<bool> = Lazy::new(|| {
@@ -177,6 +179,11 @@ pub static IS_RUNNING_AS_SHIM: Lazy<bool> = Lazy::new(|| {
         return false;
     }
 
+    // Check if running as tool stub
+    if *MISE_TOOL_STUB {
+        return true;
+    }
+
     #[cfg(unix)]
     let mise_bin = "mise";
     #[cfg(windows)]
