@@ -6,6 +6,7 @@ use std::path::Path;
 use crate::file;
 use crate::file::display_path;
 use crate::ui::progress_report::SingleReport;
+use blake3::Hasher as Blake3Hasher;
 use digest::Digest;
 use eyre::{Result, bail};
 use md5::Md5;
@@ -62,6 +63,33 @@ where
     Ok(format!("{hash:x}"))
 }
 
+pub fn hash_blake3_to_str(s: &str) -> String {
+    let mut hasher = Blake3Hasher::new();
+    hasher.update(s.as_bytes());
+    hasher.finalize().to_hex().to_string()
+}
+
+pub fn file_hash_blake3(path: &Path, pr: Option<&Box<dyn SingleReport>>) -> Result<String> {
+    let mut file = file::open(path)?;
+    if let Some(pr) = pr {
+        pr.set_length(file.metadata()?.len());
+    }
+    let mut hasher = Blake3Hasher::new();
+    let mut buf = [0; 32 * 1024];
+    loop {
+        let n = file.read(&mut buf)?;
+        if n == 0 {
+            break;
+        }
+        hasher.update(&buf[..n]);
+        if let Some(pr) = pr {
+            pr.inc(n as u64);
+        }
+    }
+    let hash = hasher.finalize();
+    Ok(format!("{}", hash.to_hex()))
+}
+
 pub fn ensure_checksum(
     path: &Path,
     checksum: &str,
@@ -70,6 +98,7 @@ pub fn ensure_checksum(
 ) -> Result<()> {
     let use_external_hasher = file::size(path).unwrap_or(u64::MAX) > 10 * 1024 * 1024;
     let actual = match algo {
+        "blake3" => file_hash_blake3(path, pr)?,
         "sha512" => {
             if use_external_hasher && file::which("sha512sum").is_some() {
                 let out = cmd!("sha512sum", path).read()?;
