@@ -43,7 +43,7 @@ fn render(module: &str, diff: Duration) -> String {
         .trim()
         .to_string();
     if diff.as_micros() > 8000 {
-        style::eblack(out).on_red().on_bright()
+        style::eblack(out).on_red().bold()
     } else if diff.as_micros() > 4000 {
         style::eblack(out).on_red()
     } else if diff.as_micros() > 2000 {
@@ -89,12 +89,14 @@ macro_rules! measure {
             let result = $block;
             end();
             result
-        } else {
+        } else if log::log_enabled!(log::Level::Trace) {
             let msg = format!($fmt);
             trace!("{msg} start");
             let result = $block;
             trace!("{msg} done");
             result
+        } else {
+            $block
         }
     }};
 }
